# superdirtpy
superdirtpy is a client library for Super Dirt written in python.

## features
- timing control
- no framework or DSL
- can be used for algorithmic composition, live coding, integration with python libraries such as numpy and scipy and developing tools for your own use.

## prerequisite
Install Tidal Cycles. Especially Super Dirt.  
https://tidalcycles.org/

## examples
- [examples](./examples/)
- https://github.com/inaba1115/algorithmic-composition-playground
